@@ -278,21 +278,13 @@ where
         let span = self.input.cur_span()?;
 
         let src = match cur!(self) {
-            Token::Str { .. } => {
-                let str = self.parse()?;
-
-                Ok(ImportSource::Str(str))
-            }
+            Token::Str { .. } => Ok(ImportSource::Str(self.parse()?)),
             Token::Function { value, .. } if *value.to_ascii_lowercase() == js_word!("url") => {
                 let func = self.parse()?;
 
                 Ok(ImportSource::Fn(func))
             }
-            Token::Url { .. } => {
-                let url = self.parse()?;
-
-                Ok(ImportSource::Url(url))
-            }
+            Token::Url { .. } => Ok(ImportSource::Url(self.parse()?)),
             _ => Err(Error::new(
                 span,
                 ErrorKind::Expected("url('https://example.com') or 'https://example.com'"),
@@ -520,7 +512,7 @@ where
         let span = self.input.cur_span()?;
 
         if is!(self, Ident) {
-            self.parse_id().map(KeyframeSelector::Ident)
+            self.parse().map(KeyframeSelector::Ident)
         } else if is!(self, Percent) {
             self.parse().map(KeyframeSelector::Percent)
         } else {
@@ -706,12 +698,12 @@ where
                 query,
             })
         } else if is!(self, Ident) {
-            let ident = self.parse_id()?;
+            let ident = self.parse()?;
             MediaQuery::Ident(ident)
         } else if eat!(self, "(") {
             if is!(self, Ident) {
                 let span = self.input.cur_span()?;
-                let id = self.parse_id()?;
+                let id = self.parse()?;
 
                 self.input.skip_ws()?;
 
@@ -844,13 +836,13 @@ where
         let start = self.input.cur_span()?.lo;
 
         let ident = if is!(self, Ident) {
-            Some(self.parse_id()?)
+            Some(self.parse()?)
         } else {
             None
         };
 
         let pseudo = if eat!(self, ":") {
-            Some(self.parse_id()?)
+            Some(self.parse()?)
         } else {
             None
         };
